@@ -6,6 +6,7 @@ from .api.resolve_api import ResolveApi as _ResolveApi
 from .api.tags_api import TagsApi as _TagsApi
 from .api.audience_api import AudienceApi as _AudienceApi
 from .api.verification_api import VerificationApi as _EmailVerificationApi
+from .api.permission_api import PermissionApi as _PermissionApi
 from .config.client_config import ClientConfig as _ClientConfig
 
 
@@ -45,3 +46,4 @@ class FullContactClient(object):
         self.tags = _TagsApi(client_config, headers)
         self.audience = _AudienceApi(client_config, headers)
         self.verification = _EmailVerificationApi(client_config, headers)
+        self.permission = _PermissionApi(client_config, headers)
